@@ -1,8 +1,23 @@
 """The registry module provides some simple convenience functions to enable
 applications to dynamically register and look-up codec classes."""
+import logging
 
-
+logger = logging.getLogger("numcodecs")
 codec_registry = dict()
+entries = {}
+
+
+def run_entrypoints():
+    import entrypoints
+    entries.clear()
+    entries.update(entrypoints.get_group_named("numcodecs.codecs"))
+
+
+try:
+    run_entrypoints()
+except (ImportError, ModuleNotFoundError):  # pragma: no cover
+    # marked "no cover" since we will include entrypoints in test env
+    pass
 
 
 def get_codec(config):
@@ -28,10 +43,15 @@ def get_codec(config):
     """
     config = dict(config)
     codec_id = config.pop('id', None)
-    cls = codec_registry.get(codec_id, None)
+    cls = codec_registry.get(codec_id)
     if cls is None:
-        raise ValueError('codec not available: %r' % codec_id)
-    return cls.from_config(config)
+        if codec_id in entries:
+            logger.debug("Auto loading codec '%s' from entrypoint", codec_id)
+            cls = entries[codec_id].load()
+            register_codec(cls, codec_id=codec_id)
+    if cls:
+        return cls.from_config(config)
+    raise ValueError('codec not available: %r' % codec_id)
 
 
 def register_codec(cls, codec_id=None):
@@ -50,4 +70,5 @@ def register_codec(cls, codec_id=None):
     """
     if codec_id is None:
         codec_id = cls.codec_id
+    logger.debug("Registering codec '%s'", codec_id)
     codec_registry[codec_id] = cls
